@@ -1,17 +1,16 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.2.5'
+__version__   = '2.3.2'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2023-March-28'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.2.5.html'
+__date__      = '2023-September-25'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.3.2.html'
 __copyright__ = "(C) 2023 Avinash Kak. Python Software Foundation."
 
 
-
 __doc__ = '''
 
 
-  You are looking at the DataPrediction co-class file in the DLStudio module.
+  You are looking at the DataPrediction co-class file in the DLStudio platform.
   For the overall documentation on DLStudio, visit:
 
            https://engineering.purdue.edu/kak/distDLS/
