@@ -1,17 +1,16 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.2.5'
+__version__   = '2.3.2'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2023-March-28'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.2.5.html'
+__date__      = '2023-September-25'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.3.2.html'
 __copyright__ = "(C) 2023 Avinash Kak. Python Software Foundation."
 
 
-
 __doc__ = '''
 
 
-  You are looking at the Seq2SeqLearning co-class file in the DLStudio module.
+  You are looking at the Seq2SeqLearning co-class file in the DLStudio platform.
   For the overall documentation on DLStudio, visit:
 
            https://engineering.purdue.edu/kak/distDLS/
@@ -35,8 +34,8 @@ SEQUENCE-TO-SEQUENCE LEARNING WITH ATTENTION:
     This class, Seq2SeqLearning, resides at the top-level of the distro.  That
     makes Seq2SeqLearning a co-class of the main DLStudio class.
 
-    In Version 2.1.0, Seq2SeqLearning contains the following two inner classes for
-    illustrating seq2seq:
+    Starting with Version 2.1.0, the Seq2SeqLearning co-class of DLStudio contains
+    the following two inner classes for illustrating seq2seq:
     
         1.  Seq2SeqWithLearnableEmbeddings
 
