@@ -8,14 +8,10 @@ if sys.version_info[0] == 3:
     from DLStudio.DLStudio import __date__
     from DLStudio.DLStudio import __url__
     from DLStudio.DLStudio import __copyright__
-    from Transformers.Transformers import Transformers
+    from Transformers.Transformers import TransformerFG
+    from Transformers.Transformers import TransformerPreLN
 else:
-    from DLStudio import __version__
-    from DLStudio import __author__
-    from DLStudio import __date__
-    from DLStudio import __url__
-    from DLStudio import __copyright__
-    from Transformers import Transformers
+    sys.exit("The transformer code in DLStudio has only been tested for Python 3")
 
 
 
